@@ -25,6 +25,10 @@ class MaintenanceHistory(models.Model):
     date = models.DateTimeField(verbose_name=_(u"Date"))
     status = models.BooleanField(default=False, verbose_name=_(u"Status"))
 
+    class Meta:
+        verbose_name = _('History')
+        verbose_name_plural = _('Historys')
+
 class MaintenanceSetting(models.Model):
 
     status = models.BooleanField(default=False, verbose_name=_(u"Status"))
@@ -38,3 +42,7 @@ class MaintenanceSetting(models.Model):
         MaintenanceHistory.objects.create(date=date, status=status)
 
         super(MaintenanceSetting, self).save(*args, **kws)
+
+    class Meta:
+        verbose_name = _('Setting')
+        verbose_name_plural = _('Settings')
